documentationtools.ModuleCrawler
================================

.. inheritance-diagram:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler
   :private-bases:

.. autoclass:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.code_root

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.ignored_directories

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.root_package_name

.. autoattribute:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__iter__

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.documentationtools.ModuleCrawler.ModuleCrawler.ModuleCrawler.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
